next_file_boundary_row

Function next_file_boundary_row 

pub fn next_file_boundary_row(
    excerpts: &[Excerpt],
    cursor_row: u32,
    count: u32,
) -> Option<u32>
Composed row of the count-th file-boundary excerpt forward of the boundary containing the current excerpt. A “file boundary” is the FIRST excerpt of each file group (per ]E semantics: jump to the start of the next file in the view).