pub struct RowAnnotationAt {
pub row: u32,
pub annotation: RowAnnotation,
}Expand description
HB.5: one annotation, and the composed row it hangs below.
Fields
row: u32The composed row of the entry this belongs to — the virtual row paints immediately below it.
annotation: RowAnnotationTrait Implementations
Sourceimpl Clone for RowAnnotationAt
impl Clone for RowAnnotationAt
Sourcefn clone(&self) -> RowAnnotationAt
fn clone(&self) -> RowAnnotationAt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RowAnnotationAt
impl Debug for RowAnnotationAt
impl Eq for RowAnnotationAt
Sourceimpl PartialEq for RowAnnotationAt
impl PartialEq for RowAnnotationAt
impl StructuralPartialEq for RowAnnotationAt