pub type ScanViewServiceHandle = Arc<dyn ScanViewService>;Expand description
Register and look up with this exact alias (the ServiceRegistry
TypeId rule).
Aliased Type
pub struct ScanViewServiceHandle { /* private fields */ }pub type ScanViewServiceHandle = Arc<dyn ScanViewService>;Register and look up with this exact alias (the ServiceRegistry
TypeId rule).
pub struct ScanViewServiceHandle { /* private fields */ }